/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Boreas SDK, Version 7.1                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* External Position */
public class ANPacket45
{
	public static final int LENGTH = 36;

	/* radians, radians, metres */
	public double[] position;
	/* metres */
	public float[] positionStandardDeviation;

	public ANPacket45()
	{
		position = new double[3];
		positionStandardDeviation = new float[3];
	}

	public ANPacket45(ANPacket packet)
	{
		position = new double[3];
		position[0] = TypeConversion.bytesToDouble(packet.data, 0);
		position[1] = TypeConversion.bytesToDouble(packet.data, 8);
		position[2] = TypeConversion.bytesToDouble(packet.data, 16);
		positionStandardDeviation = new float[3];
		positionStandardDeviation[0] = TypeConversion.bytesToFloat(packet.data,24);
		positionStandardDeviation[1] = TypeConversion.bytesToFloat(packet.data, 28);
		positionStandardDeviation[2] = TypeConversion.bytesToFloat(packet.data, 32);
	}

	public ANPacket toANPacket()
	{	
		ANPacket packet = new ANPacket(LENGTH, ANPacket.PACKET_ID_EXTERNAL_POSITION);
		TypeConversion.doubleToBytes(packet.data, 0, position[0]);
		TypeConversion.doubleToBytes(packet.data, 8, position[1]);
		TypeConversion.doubleToBytes(packet.data, 16, position[2]);		
		TypeConversion.floatToBytes(packet.data, 24, positionStandardDeviation[0]);
		TypeConversion.floatToBytes(packet.data, 28, positionStandardDeviation[1]);
		TypeConversion.floatToBytes(packet.data, 32, positionStandardDeviation[2]);			
		return packet;
	}
}
