/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Boreas SDK, Version 7.1                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* North Seeking Status */
public class ANPacket71
{
	public static final int LENGTH = 28;

	public boolean northSeekingInitialised;
	public boolean positionNotReady;
	public boolean outOfRange;
	public boolean nonOrthogonal;
	public boolean excessiveMovement;
	public boolean changeLatitude;
	public boolean changeLeverArm;
	public boolean invalidLatitude;
	public int version;
	public int progress;
	public int alignmentAttempts;
	public float coarseAlignementHeading;
	public float predictedAccuracy;

	public ANPacket71(ANPacket packet)
	{
		northSeekingInitialised = (packet.data[0] & 0x01) != 0;
		positionNotReady = (packet.data[0] & 0x02) != 0;
		outOfRange = (packet.data[0] & 0x04) != 0;
		nonOrthogonal = (packet.data[0] & 0x08) != 0;
		excessiveMovement = (packet.data[0] & 0x10) != 0;
		changeLatitude = (packet.data[0] & 0x20) != 0;
		changeLeverArm = (packet.data[0] & 0x40) != 0;
		invalidLatitude = (packet.data[0] & 0x80) != 0;
		version = TypeConversion.bytesToUInt16(packet.data, 2);
		progress = packet.data[4] & 0xFF;
		alignmentAttempts = packet.data[5] & 0xFF;
		coarseAlignementHeading = TypeConversion.bytesToFloat(packet.data, 8);
		predictedAccuracy = TypeConversion.bytesToFloat(packet.data, 12);
	}
}
