/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                   Java Language Boreas SDK, Version 7.1                    */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* External Magnetometers */
public class ANPacket75
{
	public static final int LENGTH = 17;

	public float delay;
	public float[] magnetometers;
	public boolean failure;
	public boolean overRange;

	public  ANPacket75()
	{
		magnetometers = new float[3];
	}

	public  ANPacket75(ANPacket packet)
	{
		delay = TypeConversion.bytesToFloat(packet.data, 0);
		magnetometers = new float[3];
		magnetometers[0] = TypeConversion.bytesToFloat(packet.data, 4);
		magnetometers[1] = TypeConversion.bytesToFloat(packet.data, 8);
		magnetometers[2] = TypeConversion.bytesToFloat(packet.data, 12);
		failure = (packet.data[16] & 0x01) != 0;
		overRange = (packet.data[16] & 0x02) != 0;
	}

	public ANPacket toANPacket()
	{
		ANPacket packet = new ANPacket(LENGTH, ANPacket.PACKET_ID_EXTERNAL_MAGNETOMETERS);
		TypeConversion.floatToBytes(packet.data, 0, delay);
		TypeConversion.floatToBytes(packet.data, 4, magnetometers[0]);
		TypeConversion.floatToBytes(packet.data, 8, magnetometers[1]);
		TypeConversion.floatToBytes(packet.data, 12, magnetometers[2]);
		packet.data[16] = (byte) (failure ? 0x01 : 0);
		packet.data[16] |= (byte) (overRange ? 0x02 : 0);
		return packet;
	}
}
